@@ -13,6 +13,9 @@ from cStringIO import StringIO
 re_stylesheet_import = re.compile(
     r'^((?:<!--)?\s*@import\surl*\()([^\)]+)(\);?\s*(?:-->)?)$')
 
+re_stylesheet_url = re.compile(
+    r'url\((?![A-Za-z]+://)([^\)]+)\)')
+
 class AcceptRequestData(object):
     def __init__(self):
         self.appearances = {}
@@ -42,8 +45,10 @@ class ResourceSqueezingMiddleware(object):
                 return expires, None
 
         # create extension
+        ext = None
         body, mimetype, ttl = cache[selection[0]]
-        ext = mimetypes.guess_extension(mimetype)
+        if mimetype is not None:
+            ext = mimetypes.guess_extension(mimetype)
 
         # compute digest
         out = StringIO()
@@ -95,10 +100,16 @@ class ResourceSqueezingMiddleware(object):
             # set new body
             response.body = body
 
-        # if url matches a URL we've seen in a processed document,
-        # and if it's served from this host, cache the response
+        # if url matches a URL we've seen in a processed document, and
+        # if it's served from this host, process the response body and
+        # cache it
         if request.url in accept_request_data.appearances:
             ttl = response.expires
+            if content_type == 'text/css':
+                base_path = os.path.dirname(request.url)
+                response.body = re_stylesheet_url.sub(
+                    'url(%s/\\1)' % base_path, response.body)
+                
             accept_request_data.cache[request.url] = response.body, content_type, ttl
 
         return response(environ, start_response)
@@ -108,7 +119,10 @@ class ResourceSqueezingMiddleware(object):
         stylesheets = accept_request_data.stylesheets
         appearances = accept_request_data.appearances
         cache = accept_request_data.cache
-        
+
+        if not body.strip():
+            return False, None, body
+
         tree = lxml.html.fromstring(body)
         changed = False
 
@@ -215,7 +229,7 @@ def get_url(tree, host, uri, src):
         return src
     
     if tree.xpath('.//base'):
-        url = base.attrib['href']
+        url = tree.xpath('.//base')[0].attrib['href']
     else:
         path = "/".join((host, uri))
         protocol, host, path, query, fragment = urlparse.urlsplit(path)
